# Pygame-Builtins

A pygame wrapper that was made for making games with pygame

document will be added soon...
this is a beta version and the code is ugly a new version will be made soon..

# getting an update really really soon #
